@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/python
 
 ## Copyright (C) 2007, 2008, 2009, 2010 Red Hat, Inc.
 ## Copyright (C) 2008 Novell, Inc.
@@ -16,7 +16,7 @@
 
 ## You should have received a copy of the GNU General Public License
 ## along with this program; if not, write to the Free Software
-## Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+## Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 import cups
 import dbus
@@ -31,9 +31,6 @@ import asyncipp
 from debug import *
 import debug
 
-from dbus.mainloop.glib import DBusGMainLoop
-DBusGMainLoop (set_as_default=True)
-
 CUPS_PK_NAME  = 'org.opensuse.CupsPkHelper.Mechanism'
 CUPS_PK_PATH  = '/'
 CUPS_PK_IFACE = 'org.opensuse.CupsPkHelper.Mechanism'
@@ -661,7 +658,7 @@ if __name__ == '__main__':
             print "cancel error: %s" % repr (exc)
 
         def get_file_clicked (self, button):
-            self.my_file = file ("/tmp/foo", "w")
+            self.my_file = file ("cupsd.conf", "w")
             self.conn.getFile ("/admin/conf/cupsd.conf", file=self.my_file,
                                reply_handler=self.got_file,
                                error_handler=self.get_file_error)
@@ -694,4 +691,6 @@ if __name__ == '__main__':
             print "get jobs error: %s" % repr (exc)
 
     UI ()
+    from dbus.mainloop.glib import DBusGMainLoop
+    DBusGMainLoop (set_as_default=True)
     gtk.main ()
