@@ -1,6 +1,6 @@
 #!/usr/bin/python
 
-## Copyright (C) 2007, 2008, 2009, 2010 Red Hat, Inc.
+## Copyright (C) 2007, 2008, 2009, 2010, 2011 Red Hat, Inc.
 ## Author: Tim Waugh <twaugh@redhat.com>
 
 ## This program is free software; you can redistribute it and/or modify
@@ -28,6 +28,7 @@ from debug import *
 from gettext import gettext as _
 N_ = lambda x: x
 
+cups.require("1.9.60")
 class AuthDialog(gtk.Dialog):
     AUTH_FIELD={'username': N_("Username:"),
                 'password': N_("Password:"),
@@ -132,6 +133,15 @@ class _AuthInfoCache:
         except KeyError:
             return None
 
+    def remove_auth_info (self, host=None, port=None):
+        if port == None:
+            port = 631
+
+        try:
+            del self.creds[(host,port)]
+        except KeyError:
+            return None
+
 global_authinfocache = _AuthInfoCache ()
 
 class Connection:
@@ -156,12 +166,6 @@ class Connection:
         self._lock = lock
         self._gui_event = threading.Event ()
 
-        creds = global_authinfocache.lookup_auth_info (host=host, port=port)
-        if creds != None:
-            if (creds[0] != 'root' or try_as_root):
-                (self._use_user, self._use_password) = creds
-            del creds
-
         self._connect ()
 
     def _begin_operation (self, operation):
@@ -241,8 +245,10 @@ class Connection:
             except cups.IPPError, (e, m):
                 if self._use_pk and m == 'pkcancel':
                     raise cups.IPPError (0, _("Operation canceled"))
+
                 if not self._cancel and (e == cups.IPP_NOT_AUTHORIZED or
-                                         e == cups.IPP_FORBIDDEN):
+                                         e == cups.IPP_FORBIDDEN or
+                                         e == cups.IPP_AUTHENTICATION_CANCELED):
                     self._failed (e == cups.IPP_FORBIDDEN)
                 elif not self._cancel and e == cups.IPP_SERVICE_UNAVAILABLE:
                     if self._lock:
@@ -264,6 +270,7 @@ class Connection:
                     if self._cancel and not self._cannot_auth:
                         raise cups.IPPError (0, _("Operation canceled"))
 
+                    debugprint ("%s: %s" % (e, m))
                     raise
             except cups.HTTPError, (s,):
                 if not self._cancel:
@@ -322,6 +329,12 @@ class Connection:
     def _perform_authentication (self):
         self._passes += 1
 
+        creds = global_authinfocache.lookup_auth_info (host=self._server, port=self._port)
+        if creds != None:
+            if (creds[0] != 'root' or self._try_as_root):
+                (self._use_user, self._use_password) = creds
+            del creds
+
         debugprint ("Authentication pass: %d" % self._passes)
         if self._passes == 1:
             # Haven't yet tried the operation.  Set the password
@@ -471,8 +484,9 @@ class Connection:
             self._on_authentication_response (d, response)
 
     def _on_authentication_response (self, dialog, response):
-        (self._use_user,
-         self._use_password) = dialog.get_auth_info ()
+        (user, self._use_password) = dialog.get_auth_info ()
+        if user != '':
+            self._use_user = user
         global_authinfocache.cache_auth_info ((self._use_user,
                                                self._use_password),
                                               host=self._server,
