@@ -1,6 +1,6 @@
-#!/usr/bin/env python
+#!/usr/bin/python
 
-## Copyright (C) 2010 Red Hat, Inc.
+## Copyright (C) 2010, 2011 Red Hat, Inc.
 ## Authors:
 ##  Tim Waugh <twaugh@redhat.com>
 
@@ -16,7 +16,7 @@
 
 ## You should have received a copy of the GNU General Public License
 ## along with this program; if not, write to the Free Software
-## Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+## Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 import dbus, re
 from debug import *
@@ -62,7 +62,7 @@ class DNSSDHostNamesResolver:
             hostname = hostname.encode('utf-8')
             hostname = re.sub("%(?i)[\dabcdef]{2}", expandhex, hostname)
 
-            elements = hostname.split (".")
+            elements = hostname.rsplit (".", 3)
             if len (elements) != 4:
                 self._resolved ()
                 continue
@@ -96,7 +96,7 @@ class DNSSDHostNamesResolver:
 
     def _reply (self, interface, protocol, name, stype, domain,
                 host, aprotocol, address, port, txt, flags):
-        uri = self._device_uri_by_name[(name, stype, domain)]
+        uri = self._device_uri_by_name[(name.encode ('utf-8'), stype, domain)]
         self._devices[uri].address = address
         hostname = host
         p = hostname.find(".")
