@@ -24,6 +24,9 @@ import gobject
 import gtk
 import cupshelpers
 
+import cups
+cups.require ("1.9.52")
+
 import asyncconn
 from debug import debugprint
 from gettext import gettext as _
@@ -147,13 +150,8 @@ class PPDsLoader(gobject.GObject):
 
     def _cups_connect_reply (self, conn, UNUSED):
         conn._begin_operation (_("fetching PPDs"))
-        try:
-            conn.getPPDs2 (reply_handler=self._cups_reply,
-                           error_handler=self._cups_error)
-        except AttributeError:
-            # getPPDs2 requires pycups >= 1.9.52
-            conn.getPPDs (reply_handler=self._cups_reply,
-                          error_handler=self._cups_error)
+        conn.getPPDs2 (reply_handler=self._cups_reply,
+                       error_handler=self._cups_error)
 
     def _cups_reply (self, conn, result):
         ppds = cupshelpers.ppds.PPDs (result, language=self._language)
