@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/python
 
 ## Printing troubleshooter
 
@@ -18,7 +18,7 @@
 
 ## You should have received a copy of the GNU General Public License
 ## along with this program; if not, write to the Free Software
-## Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+## Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 import cups
 import dbus
@@ -33,7 +33,6 @@ from timedops import TimedOperation, OperationCanceled
 from base import *
 
 import errordialogs
-errordialogs.set_gettext_function (_)
 from errordialogs import *
 
 DBUS_PATH="/com/redhat/PrinterSpooler"
